MRIQC measures — mriqc 0.8 documentation

# MRIQC measures

## Structural images (sMRI)

The IQMs computed are as follows:

- fwhm (nipype interface to AFNI): The FWHM of the spatial distribution of the image intensity values in units of voxels [Friedman2008]. Lower values are better

- snr (`snr()`): SNR as the mean of image values within each tissue type divided by the standard deviation of the image values within air (i.e., outside the head) [Magnota2006]. Higher values are better:

  > \[\text{SNR} = \frac{\mu_F}{\sigma_\text{air}}\]

- cnr (`cnr()`): CNR [Magnota2006], high values are better:

  > \[\text{CNR} = \frac{|\mu_\text{GM} - \mu_\text{WM} |}{\sigma_\text{air}},\]

  > where \(\sigma_\text{air}\) is the standard deviation of the noise distribution within the air (background) mask.

- fber (`fber()`): FBER, defined as the mean energy of image values within the head relative to outside the head [QAP-measures]. Higher values are better.

  > \[\text{FBER} = \frac{E[|S|^2]}{E[|N_\text{air}|^2]}.\]

- efc (`efc()`): the EFC [Atkinson1997] uses the Shannon entropy of voxel intensities as an indication of ghosting and blurring induced by head motion. Lower values are better.

  The original equation is normalized by the maximum entropy, so that the EFC can be compared across images with different dimensions.

- qi1 and qi2 (`artifact()`): Detect artifacts in the image using the method described in [Mortamet2009]. The q1 is the proportion of voxels with intensity corrupted by artifacts normalized by the number of voxels in the background. Lower values are better.

  Optionally, it also calculates qi2, the distance between the distribution of noise voxel (non-artifact background voxels) intensities, and a Rician distribution.

  The workflow to compute the artifact detection from [Mortamet2009].

- icvs_* (`volume_fractions()`): the ICV fractions of CSF, GM and WM. They should move within a normative range.

- rpve_* (`rpve()`): the rPVe of CSF, GM and WM. Lower values are better.

- inu_* (nipype interface to N4ITK): summary statistics (max, min and median) of the INU field as extracted by the N4ITK algorithm [Tustison2010]. Values closer to 1.0 are better.

- summary_*_* (`summary_stats()`): Mean, standard deviation, 5% percentile and 95% percentile of the distribution of background, CSF, GM and WM.

Most of these IQMs are migrated or derivated from [QAP-measures].

## Functional images (fMRI)

The IQMs computed are as follows:

1. `efc()` Entropy Focus Criterion
2. fber - Foreground to Background Energy Ratio
3. fwhm - Full-width half maximum smoothness of the voxels averaged across the three coordinate axes, and also for each axis [x,y,x]
4. ghost_x - Ghost to Signal Ratio
5. snr - Signal to Noise Ratio
6. dvars - Spatial standard deviation of the voxelwise temporal derivates
7. gcor - Global Correlation
8. mean_fd - Mean Fractional Displacement
9. num_fd - Number of volumes with FD greater than 0.2mm
10. perc_fd - Percent of volumes with FD greater than 0.2mm
11. outlier - Mean fraction of outliers per fMRI volume
12. quality - Median Distance Index
13. summary_{mean, stdv, p05, p95}_* - Mean, standard deviation, 5% percentile and 95% percentile of the distribution of background and foreground.

## References

> [Atkinson1997] | Atkinson et al., Automatic correction of motion artifacts in magnetic resonance images using an entropy focus criterion, IEEE Trans Med Imag 16(6):903-910, 1997. doi:10.1109/42.650886.

> [Dietrich2007] | Dietrich et al., Measurement of SNRs in MR images: influence of multichannel coils, parallel imaging and reconstruction filters, JMRI 26(2):375–385. 2007. doi:10.1002/jmri.20969.

> [Friedman2008] | Friedman, L et al., Test–retest and between‐site reliability in a multicenter fMRI study. Hum Brain Mapp, 29(8):958–972, 2008. doi:10.1002/hbm.20440.

> [Ganzetti2016] | Ganzetti et al., Intensity inhomogeneity correction of structural MR images: a data-driven approach to define input algorithm parameters. Front Neuroinform 10:10. 2016. doi:10.3389/finf.201600010.

> [Giannelli2010] | Giannelli et al., Characterization of Nyquist ghost in EPI-fMRI acquisition sequences implemented on two clinical 1.5 T MR scanner systems: effect of readout bandwidth and echo spacing. J App Clin Med Phy, 11(4). 2010. doi:10.1120/jacmp.v11i4.3237.

> [Jenkinson2002] | Jenkinson et al., Improved Optimisation for the Robust and Accurate Linear Registration and Motion Correction of Brain Images. NeuroImage, 17(2), 825-841, 2002. doi:10.1006/nimg.2002.1132.

> [Kaufman1989] | Kaufman et al., Measuring signal-to-noise ratios in MR imaging,Radiology 173(1)265–267, 1989. doi:10.1148/radiology.173.1.2781018

> [Magnota2006] | (1, 2) Magnotta, VA., & Friedman, L., Measurement of signal-to-noise and contrast-to-noise in the fBIRN multicenter imaging study. J Dig Imag 19(2):140-147, 2006. doi:10.1007/s10278-006-0264-x.

> [Mortamet2009] | (1, 2) Mortamet B et al., Automatic quality assessment in structural brain magnetic resonance imaging, Mag Res Med 62(2):365-372, 2009. doi:10.1002/mrm.21992.

> [Nichols2013] | Nichols, Notes on Creating a Standardized Version of DVARS, 2013.

> [Power2012] | Poweret al., Spurious but systematic correlations in functional connectivity MRI networks arise from subject motion, NeuroImage 59(3):2142-2154, 2012, doi:10.1016/j.neuroimage.2011.10.018.

> [QAP] | The QAP project.

> [Tustison2010] | Tustison NJ et al., N4ITK: improved N3 bias correction, IEEE Trans Med Imag, 29(6):1310-20, 2010. doi:10.1109/TMI.2010.2046908

> [QAP-measures] | (1, 2) The Quality Assessment Protocols website: Taxonomy of QA Measures.